﻿using C1.Win.C1Chart;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace AxesSettings
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }
        private void InitChart()
        {
            var grp0 = c1Chart1.ChartGroups.Group0;
            grp0.ChartData.SeriesList.Clear();

            grp0.ChartType = C1.Win.C1Chart.Chart2DTypeEnum.Gantt;
            var data = GetData();
            foreach(var item in data)
            {
                var ser = grp0.ChartData.SeriesList.AddNewSeries();
                ser.Label = item.Task;
                ser.Y.CopyDataIn(new DateTime[] { item.StartTime });
                ser.Y1.CopyDataIn(new DateTime[] { item.EndTime });
            }

            c1Chart1.ChartArea.Inverted = true;
            c1Chart1.ChartArea.AxisX.Reversed = true;

            var startDate = new DateTime(data.First().StartTime.Year, data.First().StartTime.Month, data.First().StartTime.Day, 8, 0, 0);
            var endDate = new DateTime(data.Last().EndTime.Year, data.Last().EndTime.Month, data.Last().EndTime.Day, 18, 0, 0);


            c1Chart1.ChartArea.AxisY.Min = startDate.ToOADate();
            c1Chart1.ChartArea.AxisY.Max = endDate.ToOADate();
            c1Chart1.ChartArea.AxisY.AutoMinor = false;

            //
            //Use the following for default Short Time labels: e.g: 8:00 9:00 10:00 etc.
            //
            c1Chart1.ChartArea.AxisY.AnnoFormat = C1.Win.C1Chart.FormatEnum.DateShortTime;
            c1Chart1.ChartArea.AxisY.UnitMajor = 0.05; //For 1 hour gap between labels            

            // ------------------------ OR -------------------------------------------------
            //Use the following for custom time labels: e.g: 8:00 AM  9:00 AM 10:00 AM etc.

            //c1Chart1.ChartArea.AxisY.AnnoMethod = C1.Win.C1Chart.AnnotationMethodEnum.ValueLabels;
            //var date = startDate;
            //while (date <= endDate)
            //{
            //    c1Chart1.ChartArea.AxisY.ValueLabels.Add(date.ToOADate(), date.ToString("hh:00 tt"));
            //    date = date.AddHours(1);
            //}
        }
        private List<DataItem> GetData()
        {
            var data = new List<DataItem>();
            var baseTime = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 8, 0, 0);
            data.Add(new DataItem { Task = "Task 1", StartTime = baseTime, EndTime = baseTime.AddHours(1) });
            data.Add(new DataItem { Task = "Task 2", StartTime = baseTime.AddMinutes(45), EndTime = baseTime.AddHours(2) });
            data.Add(new DataItem { Task = "Task 3", StartTime = baseTime.AddHours(2), EndTime = baseTime.AddHours(3) });
            data.Add(new DataItem { Task = "Task 4", StartTime = baseTime.AddMinutes(2 * 60 + 30), EndTime = baseTime.AddHours(6) });
            data.Add(new DataItem { Task = "Task 5", StartTime = baseTime.AddHours(4), EndTime = baseTime.AddHours(6) });
            data.Add(new DataItem { Task = "Task 6", StartTime = baseTime.AddHours(7), EndTime = baseTime.AddHours(8) });
            return data;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            InitChart();
        }
    }
    public class DataItem
    {
        public string Task { get; set; }
        public DateTime StartTime { get; set; }
        public DateTime EndTime { get; set; }
    }
}
